@@ -3,7 +3,7 @@ use warnings;
 
 =head1 NAME
 
-    Algorithm::Evolutionary::Wheel - Random selector of things depending on probabilities
+Algorithm::Evolutionary::Wheel - Random selector of things depending on probabilities
 
 =head1 SYNOPSIS
 
@@ -12,8 +12,11 @@ use warnings;
 
 =head1 DESCRIPTION
 
-Creates a "roulette wheel" for spinning and selecting stuff. It will be
-used in several places; mainly in the L<Algorithm::Evolutionary::Op::CanonicalGA>. 
+Creates a "roulette wheel" for spinning and selecting stuff. It will
+be used in several places; mainly in the
+L<Algorithm::Evolutionary::Op::CanonicalGA>.  Take care that fitness
+must be non-zero positives; since if they aren't, roulette wheel won't
+work at all
 
 =head1 METHODS
 
@@ -22,7 +25,7 @@ used in several places; mainly in the L<Algorithm::Evolutionary::Op::CanonicalGA
 package Algorithm::Evolutionary::Wheel;
 use Carp;
 
-our ($VERSION) = ( '$Revision: 2.1 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.3 $ ' =~ / (\d+\.\d+)/ ) ;
 
 =head2 new( @probabilites )
 
@@ -36,24 +39,24 @@ sub new {
   my @probs = @_;
   
   my $self;
-  $self->{_accProbs} = ();
+  $self->{'_accProbs'} = [ 0 ];
   
   my $acc = 0;
   for ( @probs ) { $acc += $_;}
+  croak "The sum of fitness is 0, can't use roulette wheel\n" if ! $acc;
   for ( @probs ) { $_ /= $acc;} #Normalizes array
-
+  
   #Now creates the accumulated array
   my $aux = 0;  
   for ( @probs ) {
-	push @{$self->{_accProbs}}, $_ + $aux;
+	push @{$self->{'_accProbs'}}, $_ + $aux;
 	$aux += $_;
   }
-
   bless $self, $class;
   return $self;
 }
 
-=head2 spin()
+=head2 spin( [$number_of_individuals = 1])
 
 Returns an individual whose probability is related to its fitness
 
@@ -61,10 +64,26 @@ Returns an individual whose probability is related to its fitness
 
 sub spin {
   my $self = shift;
+  my $number_of_individuals = shift || 1;
   my $i = 0;
-  my $rand = rand();
-  while ( $self->{_accProbs}[$i] < $rand ) { $i++ };
-  return $i;
+  my @rand;
+  for my $n ( 1..$number_of_individuals ) {
+    push @rand, rand();
+  }
+  my @individuals;
+  my @acc_probs = @{$self->{'_accProbs'}};
+  for ( my $r=0; $r<= $#rand; $r++ ) {
+      my $i = -1; # First iteration must be 0
+      do {
+	  $i++;
+      } until (( $acc_probs[$i+1] > $rand[$r] ) || ($i >= $#acc_probs ));
+      $individuals[$r] = $i;
+  }
+  if ( $number_of_individuals > 1 ) {
+    return @individuals;
+  } else {
+    return $individuals[0];
+  }
   
 }
 =head1 Copyright
@@ -72,8 +91,8 @@ sub spin {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Wheel.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2010/11/24 09:43:38 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Wheel.pm,v 3.3 2010/11/24 09:43:38 jmerelo Exp $ 
   $Author: jmerelo $ 
 
 =cut
